@@ -1,55 +1,43 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "iosconfigurations.h"
+
 #include "iosconstants.h"
 #include "iosdevice.h"
-#include "iossimulator.h"
-#include "simulatorcontrol.h"
 #include "iosprobe.h"
+#include "iossimulator.h"
+#include "iostr.h"
+#include "simulatorcontrol.h"
 
 #include <coreplugin/icore.h>
-#include <utils/algorithm.h>
-#include <utils/synchronousprocess.h>
-#include <utils/qtcassert.h>
-#include <utils/synchronousprocess.h>
+
 #include <projectexplorer/kitmanager.h>
-#include <projectexplorer/kitinformation.h>
+#include <projectexplorer/devicesupport/devicekitaspects.h>
 #include <projectexplorer/devicesupport/devicemanager.h>
+#include <projectexplorer/devicesupport/idevice.h>
 #include <projectexplorer/toolchainmanager.h>
 #include <projectexplorer/toolchain.h>
 #include <projectexplorer/gcctoolchain.h>
 #include <projectexplorer/projectexplorerconstants.h>
+#include <projectexplorer/sysrootkitaspect.h>
+#include <projectexplorer/toolchainkitaspect.h>
+#include <projectexplorer/toolchainconfigwidget.h>
+
 #include <debugger/debuggeritemmanager.h>
 #include <debugger/debuggeritem.h>
-#include <debugger/debuggerkitinformation.h>
+#include <debugger/debuggerkitaspect.h>
+
 #include <qtsupport/baseqtversion.h>
-#include <qtsupport/qtkitinformation.h>
+#include <qtsupport/qtkitaspect.h>
 #include <qtsupport/qtversionmanager.h>
 #include <qtsupport/qtversionfactory.h>
 
+#include <utils/algorithm.h>
+#include <utils/futuresynchronizer.h>
+#include <utils/qtcassert.h>
+#include <utils/qtcprocess.h>
+
 #include <QDir>
 #include <QDomDocument>
 #include <QFileInfo>
@@ -57,31 +45,32 @@
 #include <QHash>
 #include <QList>
 #include <QLoggingCategory>
-#include <QProcess>
 #include <QSettings>
-#include <QStringList>
 #include <QStandardPaths>
+#include <QStringList>
 #include <QTimer>
 
+#include <memory>
+
 using namespace ProjectExplorer;
 using namespace QtSupport;
 using namespace Utils;
 using namespace Debugger;
 
 namespace {
-Q_LOGGING_CATEGORY(kitSetupLog, "qtc.ios.kitSetup")
-Q_LOGGING_CATEGORY(iosCommonLog, "qtc.ios.common")
+static Q_LOGGING_CATEGORY(kitSetupLog, "qtc.ios.kitSetup", QtWarningMsg)
+static Q_LOGGING_CATEGORY(iosCommonLog, "qtc.ios.common", QtWarningMsg)
 }
 
-using ToolChainPair = std::pair<ClangToolChain *, ClangToolChain *>;
+using ToolchainPair = std::pair<GccToolchain *, GccToolchain *>;
 namespace Ios {
 namespace Internal {
 
+const bool IgnoreAllDevicesDefault = false;
+
 const char SettingsGroup[] = "IosConfigurations";
 const char ignoreAllDevicesKey[] = "IgnoreAllDevices";
-const char screenshotDirPathKey[] = "ScreeshotDirPath";
 
-const char provisioningTeamsTag[] = "IDEProvisioningTeams";
 const char freeTeamTag[] = "isFreeProvisioningTeam";
 const char emailTag[] = "eMail";
 const char teamNameTag[] = "teamName";
@@ -96,144 +85,129 @@ const char profileTeamIdTag[] = "TeamIdentifier";
 static const QString xcodePlistPath = QDir::homePath() + "/Library/Preferences/com.apple.dt.Xcode.plist";
 static const QString provisioningProfileDirPath = QDir::homePath() + "/Library/MobileDevice/Provisioning Profiles";
 
-static Core::Id deviceId(const QString &sdkName)
+static Id deviceId(const QString &sdkName)
 {
     if (sdkName.startsWith("iphoneos", Qt::CaseInsensitive))
         return Constants::IOS_DEVICE_TYPE;
     else if (sdkName.startsWith("iphonesimulator", Qt::CaseInsensitive))
         return Constants::IOS_SIMULATOR_TYPE;
-    return Core::Id();
+    return {};
 }
 
-static bool isSimulatorDeviceId(const Core::Id &id)
+static bool isSimulatorDeviceId(const Id &id)
 {
     return id == Constants::IOS_SIMULATOR_TYPE;
 }
 
-static QList<ClangToolChain *> clangToolChains(const QList<ToolChain *> &toolChains)
+static QList<GccToolchain *> clangToolchains(const Toolchains &toolchains)
 {
-    QList<ClangToolChain *> clangToolChains;
-    foreach (ToolChain *toolChain, toolChains)
-        if (toolChain->typeId() == ProjectExplorer::Constants::CLANG_TOOLCHAIN_TYPEID)
-            clangToolChains.append(static_cast<ClangToolChain *>(toolChain));
-    return clangToolChains;
+    QList<GccToolchain *> clangToolchains;
+    for (Toolchain *toolchain : toolchains)
+        if (toolchain->typeId() == ProjectExplorer::Constants::CLANG_TOOLCHAIN_TYPEID)
+            clangToolchains.append(static_cast<GccToolchain *>(toolchain));
+    return clangToolchains;
 }
 
-static QList<ClangToolChain *> autoDetectedIosToolChains()
+static QList<GccToolchain *> autoDetectedIosToolchains()
 {
-    const QList<ClangToolChain *> toolChains = clangToolChains(ToolChainManager::toolChains());
-    return Utils::filtered(toolChains, [](ClangToolChain *toolChain) {
+    const QList<GccToolchain *> toolchains = clangToolchains(ToolchainManager::toolchains());
+    return filtered(toolchains, [](GccToolchain *toolChain) {
         return toolChain->isAutoDetected()
                && (toolChain->displayName().startsWith("iphone")
                    || toolChain->displayName().startsWith("Apple Clang")); // TODO tool chains should be marked directly
     });
 }
 
-static ToolChainPair findToolChainForPlatform(const XcodePlatform &platform,
+static ToolchainPair findToolchainForPlatform(const XcodePlatform &platform,
                                               const XcodePlatform::ToolchainTarget &target,
-                                              const QList<ClangToolChain *> &toolChains)
+                                              const QList<GccToolchain *> &toolchains)
 {
-    ToolChainPair platformToolChains;
-    auto toolchainMatch = [](ClangToolChain *toolChain, const Utils::FileName &compilerPath, const QStringList &flags) {
+    ToolchainPair platformToolchains;
+    auto toolchainMatch = [](GccToolchain *toolChain, const FilePath &compilerPath, const QStringList &flags) {
         return compilerPath == toolChain->compilerCommand()
                 && flags == toolChain->platformCodeGenFlags()
                 && flags == toolChain->platformLinkerFlags();
     };
-    platformToolChains.first = Utils::findOrDefault(toolChains, std::bind(toolchainMatch, std::placeholders::_1,
+    platformToolchains.first = findOrDefault(toolchains, std::bind(toolchainMatch, std::placeholders::_1,
                                                                   platform.cCompilerPath,
                                                                   target.backendFlags));
-    platformToolChains.second = Utils::findOrDefault(toolChains, std::bind(toolchainMatch, std::placeholders::_1,
+    platformToolchains.second = findOrDefault(toolchains, std::bind(toolchainMatch, std::placeholders::_1,
                                                                    platform.cxxCompilerPath,
                                                                    target.backendFlags));
-    return platformToolChains;
+    return platformToolchains;
 }
 
-static QHash<XcodePlatform::ToolchainTarget, ToolChainPair> findToolChains(const QList<XcodePlatform> &platforms)
+static QHash<XcodePlatform::ToolchainTarget, ToolchainPair> findToolchains(const QList<XcodePlatform> &platforms)
 {
-    QHash<XcodePlatform::ToolchainTarget, ToolChainPair> platformToolChainHash;
-    const QList<ClangToolChain *> toolChains = autoDetectedIosToolChains();
+    QHash<XcodePlatform::ToolchainTarget, ToolchainPair> platformToolchainHash;
+    const QList<GccToolchain *> toolchains = autoDetectedIosToolchains();
     for (const XcodePlatform &platform : platforms) {
         for (const XcodePlatform::ToolchainTarget &target : platform.targets) {
-            ToolChainPair platformToolchains = findToolChainForPlatform(platform, target,
-                                                                        toolChains);
+            ToolchainPair platformToolchains = findToolchainForPlatform(platform, target,
+                                                                        toolchains);
             if (platformToolchains.first || platformToolchains.second)
-                platformToolChainHash.insert(target, platformToolchains);
+                platformToolchainHash.insert(target, platformToolchains);
         }
     }
-    return platformToolChainHash;
+    return platformToolchainHash;
 }
 
 static QSet<Kit *> existingAutoDetectedIosKits()
 {
-    return Utils::filtered(KitManager::kits(), [](Kit *kit) -> bool {
-        Core::Id deviceKind = DeviceTypeKitInformation::deviceTypeId(kit);
+    return toSet(filtered(KitManager::kits(), [](Kit *kit) -> bool {
+        Id deviceKind = RunDeviceTypeKitAspect::deviceTypeId(kit);
         return kit->isAutoDetected() && (deviceKind == Constants::IOS_DEVICE_TYPE
                                          || deviceKind == Constants::IOS_SIMULATOR_TYPE);
-    }).toSet();
+    }));
 }
 
 static void printKits(const QSet<Kit *> &kits)
 {
-    foreach (const Kit *kit, kits)
+    for (const Kit *kit : kits)
         qCDebug(kitSetupLog) << "  -" << kit->displayName();
 }
 
-static void setupKit(Kit *kit, Core::Id pDeviceType, const ToolChainPair& toolChains,
-                     const QVariant &debuggerId, const Utils::FileName &sdkPath, BaseQtVersion *qtVersion)
+static void setupKit(Kit *kit, Id pDeviceType, const ToolchainPair& toolchains,
+                     const QVariant &debuggerId, const FilePath &sdkPath, QtVersion *qtVersion)
 {
-    DeviceTypeKitInformation::setDeviceTypeId(kit, pDeviceType);
-    if (toolChains.first)
-        ToolChainKitInformation::setToolChain(kit, toolChains.first);
+    RunDeviceTypeKitAspect::setDeviceTypeId(kit, pDeviceType);
+    if (toolchains.first)
+        ToolchainKitAspect::setToolchain(kit, toolchains.first);
     else
-        ToolChainKitInformation::clearToolChain(kit, ProjectExplorer::Constants::C_LANGUAGE_ID);
-    if (toolChains.second)
-        ToolChainKitInformation::setToolChain(kit, toolChains.second);
+        ToolchainKitAspect::clearToolchain(kit, ProjectExplorer::Constants::C_LANGUAGE_ID);
+    if (toolchains.second)
+        ToolchainKitAspect::setToolchain(kit, toolchains.second);
     else
-        ToolChainKitInformation::clearToolChain(kit, ProjectExplorer::Constants::CXX_LANGUAGE_ID);
+        ToolchainKitAspect::clearToolchain(kit, ProjectExplorer::Constants::CXX_LANGUAGE_ID);
 
-    QtKitInformation::setQtVersion(kit, qtVersion);
+    QtKitAspect::setQtVersion(kit, qtVersion);
     // only replace debugger with the default one if we find an unusable one here
     // (since the user could have changed it)
-    if ((!DebuggerKitInformation::debugger(kit)
-            || !DebuggerKitInformation::debugger(kit)->isValid()
-            || DebuggerKitInformation::debugger(kit)->engineType() != LldbEngineType)
+    if ((!DebuggerKitAspect::debugger(kit)
+            || !DebuggerKitAspect::debugger(kit)->isValid()
+            || DebuggerKitAspect::debugger(kit)->engineType() != LldbEngineType)
             && debuggerId.isValid())
-        DebuggerKitInformation::setDebugger(kit, debuggerId);
+        DebuggerKitAspect::setDebugger(kit, debuggerId);
 
-    kit->setMutable(DeviceKitInformation::id(), true);
-    kit->setSticky(QtKitInformation::id(), true);
-    kit->setSticky(ToolChainKitInformation::id(), true);
-    kit->setSticky(DeviceTypeKitInformation::id(), true);
-    kit->setSticky(SysRootKitInformation::id(), true);
-    kit->setSticky(DebuggerKitInformation::id(), false);
+    kit->setSticky(QtKitAspect::id(), true);
+    kit->setSticky(ToolchainKitAspect::id(), true);
+    kit->setSticky(RunDeviceTypeKitAspect::id(), true);
+    kit->setSticky(SysRootKitAspect::id(), true);
+    kit->setSticky(DebuggerKitAspect::id(), false);
 
-    SysRootKitInformation::setSysRoot(kit, sdkPath);
+    SysRootKitAspect::setSysRoot(kit, sdkPath);
 }
 
-static QVersionNumber findXcodeVersion()
+static QVersionNumber findXcodeVersion(const FilePath &developerPath)
 {
-    Utils::SynchronousProcess pkgUtilProcess;
-    Utils::SynchronousProcessResponse resp =
-            pkgUtilProcess.runBlocking("pkgutil", QStringList("--pkg-info-plist=com.apple.pkg.Xcode"));
-    if (resp.result == Utils::SynchronousProcessResponse::Finished) {
-        QDomDocument xcodeVersionDoc;
-        if (xcodeVersionDoc.setContent(resp.allRawOutput())) {
-            QDomNodeList nodes = xcodeVersionDoc.elementsByTagName(QStringLiteral("key"));
-            for (int i = 0; i < nodes.count(); ++i) {
-                QDomElement elem = nodes.at(i).toElement();
-                if (elem.text().compare(QStringLiteral("pkg-version")) == 0) {
-                    QString versionStr = elem.nextSiblingElement().text();
-                    return  QVersionNumber::fromString(versionStr);
-                }
-            }
-        } else {
-            qCDebug(iosCommonLog) << "Error finding Xcode version. Cannot parse xml output from pkgutil.";
-        }
+    const FilePath xcodeInfo = developerPath.parentDir().pathAppended("Info.plist");
+    if (xcodeInfo.exists()) {
+        QSettings settings(xcodeInfo.toUrlishString(), QSettings::NativeFormat);
+        return QVersionNumber::fromString(settings.value("CFBundleShortVersionString").toString());
     } else {
-        qCDebug(iosCommonLog) << "Error finding Xcode version. pkgutil command failed.";
+        qCDebug(iosCommonLog) << "Error finding Xcode version." << xcodeInfo.toUserOutput() <<
+                                 "does not exist.";
     }
-
-    qCDebug(iosCommonLog) << "Error finding Xcode version. Unknow error.";
     return QVersionNumber();
 }
 
@@ -241,14 +215,14 @@ static QByteArray decodeProvisioningProfile(const QString &path)
 {
     QTC_ASSERT(!path.isEmpty(), return QByteArray());
 
-    Utils::SynchronousProcess p;
-    p.setTimeoutS(3);
+    Process p;
     // path is assumed to be valid file path to .mobileprovision
-    const QStringList args = {"smime", "-inform", "der", "-verify", "-in", path};
-    Utils::SynchronousProcessResponse res = p.runBlocking("openssl", args);
-    if (res.result != Utils::SynchronousProcessResponse::Finished)
+    p.setCommand({"openssl", {"smime", "-inform", "der", "-verify", "-in", path}});
+    using namespace std::chrono_literals;
+    p.runBlocking(3s);
+    if (p.result() != ProcessResult::FinishedWithSuccess)
         qCDebug(iosCommonLog) << "Reading signed provisioning file failed" << path;
-    return res.stdOut().toLatin1();
+    return p.cleanedStdOut().toLatin1();
 }
 
 void IosConfigurations::updateAutomaticKitList()
@@ -259,11 +233,11 @@ void IosConfigurations::updateAutomaticKitList()
     qCDebug(kitSetupLog) << "Developer path:" << developerPath();
 
     // target -> tool chain
-    const auto targetToolChainHash = findToolChains(platforms);
+    const auto targetToolchainHash = findToolchains(platforms);
 
-    const auto qtVersions = QtVersionManager::versions([](const BaseQtVersion *v) {
+    const auto qtVersions = toSet(QtVersionManager::versions([](const QtVersion *v) {
         return v->isValid() && v->type() == Constants::IOSQT;
-    }).toSet();
+    }));
 
     const DebuggerItem *possibleDebugger = DebuggerItemManager::findByEngineType(LldbEngineType);
     const QVariant debuggerId = (possibleDebugger ? possibleDebugger->id() : QVariant());
@@ -274,8 +248,8 @@ void IosConfigurations::updateAutomaticKitList()
     QSet<Kit *> resultingKits;
     for (const XcodePlatform &platform : platforms) {
         for (const auto &sdk : platform.sdks) {
-            const auto targets = Utils::filtered(platform.targets,
-                                           [&sdk](const XcodePlatform::ToolchainTarget &target) {
+            const auto targets = filtered(platform.targets,
+                                          [&sdk](const XcodePlatform::ToolchainTarget &target) {
                  return sdk.architectures.first() == target.architecture;
             });
             if (targets.empty())
@@ -283,26 +257,26 @@ void IosConfigurations::updateAutomaticKitList()
 
             const auto target = targets.front();
 
-            const ToolChainPair &platformToolchains = targetToolChainHash.value(target);
+            const ToolchainPair &platformToolchains = targetToolchainHash.value(target);
             if (!platformToolchains.first && !platformToolchains.second) {
                 qCDebug(kitSetupLog) << "  - No tool chain found";
                 continue;
             }
-            Core::Id pDeviceType = deviceId(sdk.directoryName);
+            Id pDeviceType = deviceId(sdk.directoryName);
             if (!pDeviceType.isValid()) {
                 qCDebug(kitSetupLog) << "Unsupported/Invalid device type" << sdk.directoryName;
                 continue;
             }
 
-            for (BaseQtVersion *qtVersion : qtVersions) {
+            for (QtVersion *qtVersion : qtVersions) {
                 qCDebug(kitSetupLog) << "  - Qt version:" << qtVersion->displayName();
-                Kit *kit = Utils::findOrDefault(existingKits, [&pDeviceType, &platformToolchains, &qtVersion](const Kit *kit) {
+                Kit *kit = findOrDefault(existingKits, [&pDeviceType, &platformToolchains, &qtVersion](const Kit *kit) {
                     // we do not compare the sdk (thus automatically upgrading it in place if a
                     // new Xcode is used). Change?
-                    return DeviceTypeKitInformation::deviceTypeId(kit) == pDeviceType
-                            && ToolChainKitInformation::toolChain(kit, ProjectExplorer::Constants::CXX_LANGUAGE_ID) == platformToolchains.second
-                            && ToolChainKitInformation::toolChain(kit, ProjectExplorer::Constants::C_LANGUAGE_ID) == platformToolchains.first
-                            && QtKitInformation::qtVersion(kit) == qtVersion;
+                    return RunDeviceTypeKitAspect::deviceTypeId(kit) == pDeviceType
+                            && ToolchainKitAspect::cxxToolchain(kit) == platformToolchains.second
+                            && ToolchainKitAspect::cToolchain(kit) == platformToolchains.first
+                            && QtKitAspect::qtVersion(kit) == qtVersion;
                 });
                 QTC_ASSERT(!resultingKits.contains(kit), continue);
                 if (kit) {
@@ -312,16 +286,15 @@ void IosConfigurations::updateAutomaticKitList()
                     kit->unblockNotification();
                 } else {
                     qCDebug(kitSetupLog) << "    - Setting up new kit";
-                    kit = new Kit;
-                    kit->blockNotification();
-                    kit->setAutoDetected(true);
-                    const QString baseDisplayName = isSimulatorDeviceId(pDeviceType)
-                            ? tr("%1 Simulator").arg(qtVersion->unexpandedDisplayName())
-                            : qtVersion->unexpandedDisplayName();
-                    kit->setUnexpandedDisplayName(baseDisplayName);
-                    setupKit(kit, pDeviceType, platformToolchains, debuggerId, sdk.path, qtVersion);
-                    kit->unblockNotification();
-                    KitManager::registerKit(kit);
+                    const auto init = [&](Kit *k) {
+                        k->setAutoDetected(true);
+                        const QString baseDisplayName = isSimulatorDeviceId(pDeviceType)
+                                ? Tr::tr("%1 Simulator").arg(qtVersion->unexpandedDisplayName())
+                                : qtVersion->unexpandedDisplayName();
+                        k->setUnexpandedDisplayName(baseDisplayName);
+                        setupKit(k, pDeviceType, platformToolchains, debuggerId, sdk.path, qtVersion);
+                    };
+                    kit = KitManager::registerKit(init);
                 }
                 resultingKits.insert(kit);
             }
@@ -331,8 +304,7 @@ void IosConfigurations::updateAutomaticKitList()
     existingKits.subtract(resultingKits);
     qCDebug(kitSetupLog) << "Removing unused kits:";
     printKits(existingKits);
-    foreach (Kit *kit, existingKits)
-        KitManager::deregisterKit(kit);
+    KitManager::deregisterKits(toList(existingKits));
 }
 
 static IosConfigurations *m_instance = nullptr;
@@ -344,8 +316,17 @@ IosConfigurations *IosConfigurations::instance()
 
 void IosConfigurations::initialize()
 {
-    QTC_CHECK(m_instance == 0);
-    m_instance = new IosConfigurations(0);
+    QTC_CHECK(m_instance == nullptr);
+    m_instance = new IosConfigurations(nullptr);
+}
+
+void IosConfigurations::kitsRestored()
+{
+    disconnect(KitManager::instance(), &KitManager::kitsLoaded,
+               this, &IosConfigurations::kitsRestored);
+    IosConfigurations::updateAutomaticKitList();
+    connect(QtVersionManager::instance(), &QtVersionManager::qtVersionsChanged,
+            IosConfigurations::instance(), &IosConfigurations::updateAutomaticKitList);
 }
 
 bool IosConfigurations::ignoreAllDevices()
@@ -361,20 +342,7 @@ void IosConfigurations::setIgnoreAllDevices(bool ignoreDevices)
     }
 }
 
-void IosConfigurations::setScreenshotDir(const FileName &path)
-{
-    if (m_instance->m_screenshotDir != path) {
-        m_instance->m_screenshotDir = path;
-        m_instance->save();
-    }
-}
-
-FileName IosConfigurations::screenshotDir()
-{
-    return m_instance->m_screenshotDir;
-}
-
-FileName IosConfigurations::developerPath()
+FilePath IosConfigurations::developerPath()
 {
     return m_instance->m_developerPath;
 }
@@ -386,10 +354,9 @@ QVersionNumber IosConfigurations::xcodeVersion()
 
 void IosConfigurations::save()
 {
-    QSettings *settings = Core::ICore::settings();
+    QtcSettings *settings = Core::ICore::settings();
     settings->beginGroup(SettingsGroup);
-    settings->setValue(ignoreAllDevicesKey, m_ignoreAllDevices);
-    settings->setValue(screenshotDirPathKey, m_screenshotDir.toString());
+    settings->setValueWithDefault(ignoreAllDevicesKey, m_ignoreAllDevices, IgnoreAllDevicesDefault);
     settings->endGroup();
 }
 
@@ -397,19 +364,15 @@ IosConfigurations::IosConfigurations(QObject *parent)
     : QObject(parent)
 {
     load();
+    connect(KitManager::instance(), &KitManager::kitsLoaded,
+            this, &IosConfigurations::kitsRestored);
 }
 
 void IosConfigurations::load()
 {
-    QSettings *settings = Core::ICore::settings();
+    QtcSettings *settings = Core::ICore::settings();
     settings->beginGroup(SettingsGroup);
-    m_ignoreAllDevices = settings->value(ignoreAllDevicesKey, false).toBool();
-    m_screenshotDir = FileName::fromString(settings->value(screenshotDirPathKey).toString());
-    if (!m_screenshotDir.exists()) {
-        QString defaultDir = QStandardPaths::standardLocations(QStandardPaths::PicturesLocation).first();
-        m_screenshotDir = FileName::fromString(defaultDir);
-    }
-
+    m_ignoreAllDevices = settings->value(ignoreAllDevicesKey, IgnoreAllDevicesDefault).toBool();
     settings->endGroup();
 }
 
@@ -417,16 +380,16 @@ void IosConfigurations::updateSimulators()
 {
     // currently we have just one simulator
     DeviceManager *devManager = DeviceManager::instance();
-    Core::Id devId = Constants::IOS_SIMULATOR_DEVICE_ID;
+    Id devId = Constants::IOS_SIMULATOR_DEVICE_ID;
     IDevice::ConstPtr dev = devManager->find(devId);
-    if (dev.isNull()) {
+    if (!dev) {
         dev = IDevice::ConstPtr(new IosSimulator(devId));
         devManager->addDevice(dev);
     }
-    SimulatorControl::updateAvailableSimulators();
+    Utils::futureSynchronizer()->addFuture(SimulatorControl::updateAvailableSimulators(this));
 }
 
-void IosConfigurations::setDeveloperPath(const FileName &devPath)
+void IosConfigurations::setDeveloperPath(const FilePath &devPath)
 {
     static bool hasDevPath = false;
     if (devPath != m_instance->m_developerPath) {
@@ -439,7 +402,7 @@ void IosConfigurations::setDeveloperPath(const FileName &devPath)
             m_instance->updateSimulators();
 
             // Find xcode version.
-            m_instance->m_xcodeVersion = findXcodeVersion();
+            m_instance->m_xcodeVersion = findXcodeVersion(m_instance->m_developerPath);
         }
     }
 }
@@ -466,6 +429,46 @@ void IosConfigurations::initializeProvisioningData()
             std::bind(&IosConfigurations::loadProvisioningData, this, true));
 }
 
+static QVariantMap getTeamMap(const QSettings &xcodeSettings)
+{
+    // Check the version for Xcode 16.2 and later
+    const QVariantMap teamMap = xcodeSettings.value("IDEProvisioningTeamByIdentifier").toMap();
+    if (!teamMap.isEmpty())
+        return teamMap;
+    // Fall back to setting from Xcode < 16.2
+    return xcodeSettings.value("IDEProvisioningTeams").toMap();
+}
+
+static QHash<QString, QString> getIdentifierToEmail(const QSettings &xcodeSettings)
+{
+    // Available for Xcode 16.2 and later, where the keys for the IDEProvisioningTeamByIdentifier
+    // (see getTeamMap) are identifiers, and the "email" is in yet another "map":
+    // "DVTDeveloperAccountManagerAppleIDLists" => {
+    //   "IDE.Identifiers.Prod" => [
+    //     0 => {
+    //       "identifier" => "xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx"
+    //     }
+    //   ]
+    //   "IDE.Prod" => [
+    //     0 => {
+    //       "username" => "xxxx"
+    //     }
+    //   ]
+    // }
+    const QVariantMap accountMap
+        = xcodeSettings.value("DVTDeveloperAccountManagerAppleIDLists").toMap();
+    const QVariantList idList = accountMap.value("IDE.Identifiers.Prod").toList();
+    const QVariantList emailList = accountMap.value("IDE.Prod").toList();
+    QHash<QString, QString> result;
+    const int size = std::min(idList.size(), emailList.size());
+    for (int i = 0; i < size; ++i) {
+        result.insert(
+            idList.at(i).toMap().value("identifier").toString(),
+            emailList.at(i).toMap().value("username").toString());
+    }
+    return result;
+}
+
 void IosConfigurations::loadProvisioningData(bool notify)
 {
     m_developerTeams.clear();
@@ -473,24 +476,31 @@ void IosConfigurations::loadProvisioningData(bool notify)
 
     // Populate Team id's
     const QSettings xcodeSettings(xcodePlistPath, QSettings::NativeFormat);
-    const QVariantMap teamMap = xcodeSettings.value(provisioningTeamsTag).toMap();
+    const QVariantMap teamMap = getTeamMap(xcodeSettings);
+    const QHash<QString, QString> identifierToName = getIdentifierToEmail(xcodeSettings);
     QList<QVariantMap> teams;
-    QMapIterator<QString, QVariant> accountiterator(teamMap);
-    while (accountiterator.hasNext()) {
-        accountiterator.next();
-        QVariantMap teamInfo = accountiterator.value().toMap();
-        int provisioningTeamIsFree = teamInfo.value(freeTeamTag).toBool() ? 1 : 0;
-        teamInfo[freeTeamTag] = provisioningTeamIsFree;
-        teamInfo[emailTag] = accountiterator.key();
-        teams.append(teamInfo);
+    for (auto accountiterator = teamMap.cbegin(), end = teamMap.cend();
+            accountiterator != end; ++accountiterator) {
+        // difference between Qt 5 (map) and Qt 6 (list of maps)
+        const bool isList = accountiterator->userType() == QMetaType::QVariantList;
+        const QVariantList teamsList = isList ? accountiterator.value().toList()
+                                              : QVariantList({accountiterator.value()});
+        for (const QVariant &teamInfoIt : teamsList) {
+            QVariantMap teamInfo = teamInfoIt.toMap();
+            int provisioningTeamIsFree = teamInfo.value(freeTeamTag).toBool() ? 1 : 0;
+            teamInfo[freeTeamTag] = provisioningTeamIsFree;
+            teamInfo[emailTag]
+                = identifierToName.value(accountiterator.key(), /*default=*/accountiterator.key());
+            teams.append(teamInfo);
+        }
     }
 
     // Sort team id's to move the free provisioning teams at last of the list.
-    Utils::sort(teams, [](const QVariantMap &teamInfo1, const QVariantMap &teamInfo2) {
+    sort(teams, [](const QVariantMap &teamInfo1, const QVariantMap &teamInfo2) {
         return teamInfo1.value(freeTeamTag).toInt() < teamInfo2.value(freeTeamTag).toInt();
     });
 
-    foreach (auto teamInfo, teams) {
+    for (auto teamInfo : std::as_const(teams)) {
         auto team = std::make_shared<DevelopmentTeam>();
         team->m_name = teamInfo.value(teamNameTag).toString();
         team->m_email = teamInfo.value(emailTag).toString();
@@ -501,7 +511,10 @@ void IosConfigurations::loadProvisioningData(bool notify)
 
     const QDir provisioningProflesDir(provisioningProfileDirPath);
     const QStringList filters = {"*.mobileprovision"};
-    foreach (QFileInfo fileInfo, provisioningProflesDir.entryInfoList(filters, QDir::NoDotAndDotDot | QDir::Files)) {
+    const QList<QFileInfo> fileInfos = provisioningProflesDir.entryInfoList(filters,
+                                                                            QDir::NoDotAndDotDot
+                                                                                | QDir::Files);
+    for (const QFileInfo &fileInfo : fileInfos) {
         QDomDocument provisioningDoc;
         auto profile = std::make_shared<ProvisioningProfile>();
         QString teamID;
@@ -558,7 +571,7 @@ DevelopmentTeamPtr IosConfigurations::developmentTeam(const QString &teamID)
     QTC_CHECK(m_instance);
     m_instance->initializeProvisioningData();
     return findOrDefault(m_instance->m_developerTeams,
-                         Utils::equal(&DevelopmentTeam::identifier, teamID));
+                         equal(&DevelopmentTeam::identifier, teamID));
 }
 
 const ProvisioningProfiles &IosConfigurations::provisioningProfiles()
@@ -572,63 +585,68 @@ ProvisioningProfilePtr IosConfigurations::provisioningProfile(const QString &pro
 {
     QTC_CHECK(m_instance);
     m_instance->initializeProvisioningData();
-    return Utils::findOrDefault(m_instance->m_provisioningProfiles,
-                                Utils::equal(&ProvisioningProfile::identifier, profileID));
+    return findOrDefault(m_instance->m_provisioningProfiles,
+                                equal(&ProvisioningProfile::identifier, profileID));
 }
 
-static ClangToolChain *createToolChain(const XcodePlatform &platform,
-                                       const XcodePlatform::ToolchainTarget &target,
-                                       Core::Id l)
+class IosToolchainFactory final : public ToolchainFactory
 {
-    if (!l.isValid())
-        return nullptr;
+public:
+    IosToolchainFactory()
+    {
+        setSupportedLanguages({ProjectExplorer::Constants::C_LANGUAGE_ID,
+                               ProjectExplorer::Constants::CXX_LANGUAGE_ID});
+    }
 
-    if (l != Core::Id(ProjectExplorer::Constants::C_LANGUAGE_ID)
-            && l != Core::Id(ProjectExplorer::Constants::CXX_LANGUAGE_ID))
-        return nullptr;
+    Toolchains autoDetect(const ToolchainDetector &detector) const final;
 
-    ClangToolChain *toolChain = new ClangToolChain(ToolChain::AutoDetection);
-    toolChain->setLanguage(l);
-    toolChain->setDisplayName(target.name);
-    toolChain->setPlatformCodeGenFlags(target.backendFlags);
-    toolChain->setPlatformLinkerFlags(target.backendFlags);
-    toolChain->resetToolChain(l == Core::Id(ProjectExplorer::Constants::CXX_LANGUAGE_ID) ?
-                                  platform.cxxCompilerPath : platform.cCompilerPath);
+    std::unique_ptr<ToolchainConfigWidget> createConfigurationWidget(
+        const ToolchainBundle &bundle) const override
+    {
+        return GccToolchain::createConfigurationWidget(bundle);
+    }
+};
 
-    return toolChain;
-}
-
-QSet<Core::Id> IosToolChainFactory::supportedLanguages() const
+Toolchains IosToolchainFactory::autoDetect(const ToolchainDetector &detector) const
 {
-    return {
-        ProjectExplorer::Constants::C_LANGUAGE_ID,
-        ProjectExplorer::Constants::CXX_LANGUAGE_ID
-    };
-}
+    if (detector.device->type() != ProjectExplorer::Constants::DESKTOP_DEVICE_TYPE)
+        return {};
 
-QList<ToolChain *> IosToolChainFactory::autoDetect(const QList<ToolChain *> &existingToolChains)
-{
-    QList<ClangToolChain *> existingClangToolChains = clangToolChains(existingToolChains);
+    QList<GccToolchain *> existingClangToolchains = clangToolchains(detector.alreadyKnown);
     const QList<XcodePlatform> platforms = XcodeProbe::detectPlatforms().values();
-    QList<ClangToolChain *> toolChains;
-    toolChains.reserve(platforms.size());
-    foreach (const XcodePlatform &platform, platforms) {
+    Toolchains toolchains;
+    toolchains.reserve(platforms.size());
+    for (const XcodePlatform &platform : platforms) {
         for (const XcodePlatform::ToolchainTarget &target : platform.targets) {
-            ToolChainPair platformToolchains = findToolChainForPlatform(platform, target,
-                                                                        existingClangToolChains);
-            auto createOrAdd = [&](ClangToolChain* toolChain, Core::Id l) {
+            ToolchainPair platformToolchains = findToolchainForPlatform(platform, target,
+                                                                        existingClangToolchains);
+            auto createOrAdd = [&](GccToolchain *toolChain, Id l) {
                 if (!toolChain) {
-                    toolChain = createToolChain(platform, target, l);
-                    existingClangToolChains.append(toolChain);
+                    toolChain = new GccToolchain(ProjectExplorer::Constants::CLANG_TOOLCHAIN_TYPEID,
+                                                 GccToolchain::Clang);
+                    toolChain->setPriority(Toolchain::PriorityLow);
+                    toolChain->setDetection(Toolchain::AutoDetection);
+                    toolChain->setLanguage(l);
+                    toolChain->setDisplayName(target.name);
+                    toolChain->setPlatformCodeGenFlags(target.backendFlags);
+                    toolChain->setPlatformLinkerFlags(target.backendFlags);
+                    toolChain->resetToolchain(l == ProjectExplorer::Constants::CXX_LANGUAGE_ID ?
+                                                  platform.cxxCompilerPath : platform.cCompilerPath);
+                    existingClangToolchains.append(toolChain);
                 }
-                toolChains.append(toolChain);
+                toolchains.append(toolChain);
             };
 
             createOrAdd(platformToolchains.first, ProjectExplorer::Constants::C_LANGUAGE_ID);
             createOrAdd(platformToolchains.second, ProjectExplorer::Constants::CXX_LANGUAGE_ID);
         }
     }
-    return Utils::transform(toolChains, [](ClangToolChain *tc) -> ToolChain * { return tc; });
+    return toolchains;
+}
+
+void setupIosToolchain()
+{
+    static IosToolchainFactory theIosToolchainFactory;
 }
 
 QString DevelopmentTeam::identifier() const
@@ -643,15 +661,15 @@ QString DevelopmentTeam::displayName() const
 
 QString DevelopmentTeam::details() const
 {
-    return tr("%1 - Free Provisioning Team : %2")
-            .arg(m_identifier).arg(m_freeTeam ? tr("Yes") : tr("No"));
+    return Tr::tr("%1 - Free Provisioning Team : %2")
+            .arg(m_identifier).arg(m_freeTeam ? Tr::tr("Yes") : Tr::tr("No"));
 }
 
 QDebug &operator<<(QDebug &stream, DevelopmentTeamPtr team)
 {
     QTC_ASSERT(team, return stream);
     stream << team->displayName() << team->identifier() << team->isFreeProfile();
-    foreach (auto profile, team->m_profiles)
+    for (const auto &profile : std::as_const(team->m_profiles))
         stream << "Profile:" << profile;
     return stream;
 }
@@ -668,8 +686,8 @@ QString ProvisioningProfile::displayName() const
 
 QString ProvisioningProfile::details() const
 {
-    return tr("Team: %1\nApp ID: %2\nExpiration date: %3").arg(m_team->identifier()).arg(m_appID)
-            .arg(m_expirationDate.toLocalTime().toString(Qt::SystemLocaleShortDate));
+    return Tr::tr("Team: %1\nApp ID: %2\nExpiration date: %3").arg(m_team->identifier()).arg(m_appID)
+            .arg(QLocale::system().toString(m_expirationDate.toLocalTime(), QLocale::ShortFormat));
 }
 
 QDebug &operator<<(QDebug &stream, std::shared_ptr<ProvisioningProfile> profile)
