@@ -1,27 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
@@ -56,12 +34,27 @@ public:
         PowerPCArchitecture,
         ShArchitecture,
         AvrArchitecture,
+        Avr32Architecture,
         XtensaArchitecture,
         Mcs51Architecture,
+        Mcs251Architecture,
         AsmJsArchitecture,
         Stm8Architecture,
         Msp430Architecture,
         Rl78Architecture,
+        C166Architecture,
+        V850Architecture,
+        Rh850Architecture,
+        RxArchitecture,
+        K78Architecture,
+        M68KArchitecture,
+        M32CArchitecture,
+        M16CArchitecture,
+        M32RArchitecture,
+        R32CArchitecture,
+        CR16Architecture,
+        RiscVArchitecture,
+        LoongArchArchitecture,
         UnknownArchitecture
     };
 
@@ -98,7 +91,8 @@ public:
         WindowsMsvc2015Flavor,
         WindowsMsvc2017Flavor,
         WindowsMsvc2019Flavor,
-        WindowsLastMsvcFlavor = WindowsMsvc2019Flavor,
+        WindowsMsvc2022Flavor,
+        WindowsLastMsvcFlavor = WindowsMsvc2022Flavor,
         WindowsMSysFlavor,
         WindowsCEFlavor,
 
@@ -109,6 +103,9 @@ public:
         RtosFlavor,
         GenericFlavor,
 
+        // Yocto
+        PokyFlavor,
+
         UnknownFlavor // keep last in this enum!
     };
 
@@ -134,7 +131,6 @@ public:
     bool operator != (const Abi &other) const;
     bool operator == (const Abi &other) const;
     bool isCompatibleWith(const Abi &other) const;
-    bool isFullyCompatibleWith(const Abi &other) const;
 
     bool isValid() const;
     bool isNull() const;
@@ -148,17 +144,19 @@ public:
     QString toString() const;
     QString param() const;
 
+    QString toAndroidAbi() const;
+
     static QString toString(const Architecture &a);
     static QString toString(const OS &o);
     static QString toString(const OSFlavor &of);
     static QString toString(const BinaryFormat &bf);
     static QString toString(int w);
 
-    static Architecture architectureFromString(const QStringRef &a);
-    static OS osFromString(const QStringRef &o);
-    static OSFlavor osFlavorFromString(const QStringRef &of, const OS os);
-    static BinaryFormat binaryFormatFromString(const QStringRef &bf);
-    static unsigned char wordWidthFromString(const QStringRef &w);
+    static Architecture architectureFromString(const QString &a);
+    static OS osFromString(const QString &o);
+    static OSFlavor osFlavorFromString(const QString &of, const OS os);
+    static BinaryFormat binaryFormatFromString(const QString &bf);
+    static unsigned char wordWidthFromString(const QString &w);
 
     static OSFlavor registerOsFlavor(const std::vector<OS> &oses, const QString &flavorName);
     static QList<OSFlavor> flavorsForOs(const OS &o);
@@ -170,6 +168,15 @@ public:
     static Abi hostAbi();
     static Abis abisOfBinary(const Utils::FilePath &path);
 
+    friend auto qHash(const ProjectExplorer::Abi &abi)
+    {
+        int h = abi.architecture()
+                + (abi.os() << 3)
+                + (abi.osFlavor() << 6)
+                + (abi.binaryFormat() << 10)
+                + (abi.wordWidth() << 13);
+        return QT_PREPEND_NAMESPACE(qHash)(h);
+    }
 
 private:
     Architecture m_architecture;
@@ -180,14 +187,4 @@ private:
     QString m_param;
 };
 
-inline int qHash(const ProjectExplorer::Abi &abi)
-{
-    int h = abi.architecture()
-            + (abi.os() << 3)
-            + (abi.osFlavor() << 6)
-            + (abi.binaryFormat() << 10)
-            + (abi.wordWidth() << 13);
-    return QT_PREPEND_NAMESPACE(qHash)(h);
-}
-
 } // namespace ProjectExplorer
